@@ -5,6 +5,7 @@ import string
 import re
 from lvmui_constants import *
 from BlockDeviceModel import *
+from CommandError import CommandError
 from execute import execWithCapture, execWithCaptureErrorStatus, execWithCaptureStatus, ProgressPopup
 import gettext
 _ = gettext.gettext
@@ -98,7 +99,7 @@ EXTENDED_PARTITION=_("Extended partition")
 #Translator: the line below refers to a standard linux swap partition.
 SWAP_IN_USE=_("Swap partition currently in use")
 FOREIGN_BOOT_PARTITION=_("Foreign boot partition")
-AUTOPARTITION_FAILURE=_("Autopartition failure")
+AUTOPARTITION_FAILURE=_("Autopartition failure: %s")
 
 VG_NAME_IDX = 0
 VG_SYSID_IDX = 1
@@ -728,6 +729,10 @@ class lvm_model:
       except BlockDeviceErr:
         self.__block_device_model.reload()
         raise CommandError('FATAL', AUTOPARTITION_FAILURE % devname)
+      except AttributeError:
+        self.__block_device_model.reload()
+        raise CommandError('FATAL', AUTOPARTITION_FAILURE % devname)
+
     return pv.get_path()
   
   def __set_VGs_props(self):
